@@ -6,7 +6,7 @@ if(getRversion() >= "2.15.1")  utils::globalVariables(".")
 verify_con <- function(x, dir = tempdir()) {
   if (!inherits(x, "src")) {
     sqlite_file <- tempfile(fileext = ".sqlite3", tmpdir = dir)
-    message("Not a valid src. Creating a src_sqlite for you at:")
+    message("No database was specified so I created one for you at:")
     message(sqlite_file)
     x <- dplyr::src_sqlite(path = sqlite_file, create = TRUE)
   }
